<?php
/*
 * Tutorial: How to Replace an Attachment Easily in WordPress
 * URL: https://www.rafaelcardero.com/tutorials/how-to-replace-an-attachment-easily-in-wordpress/
 */

/* -----------------------------------------------------------------------------
 * - Caching issue
 * ---------------------------------------------------------------------------*/

/*
 * Adds a version number to the URL of an attachment to make it cache-safe.
 */
function ns_make_attachment_cache_safe($url, $post_ID){
    
    $version = get_post_meta($post_ID, '_ns_version_cf', true);
    $version = intval($version);
    return add_query_arg('ver', urlencode($version), $url);
}
add_filter('wp_get_attachment_url', 'ns_make_attachment_cache_safe', 10, 2);

/*
 * Updates the version of an attachment each time it is replaced.
 */
function ns_update_attachment_version($args){
    
    if(isset($args['post_id'])){
        $post_ID = $args['post_id'];
        $version = get_post_meta($post_ID, '_ns_version_cf', true);
        $version++;
        update_post_meta($post_ID, '_ns_version_cf', $version);
    }
}
add_action('wp_handle_replace', 'ns_update_attachment_version', 10, 1);